"use strict";
var ts = require("typescript");
var path_1 = require("path");
var sys = ts.sys;
var useCaseSensitiveFileNames = sys.useCaseSensitiveFileNames, newLine = sys.newLine, getCurrentDirectory = sys.getCurrentDirectory;
function getNewLine() {
    return newLine;
}
exports.getNewLine = getNewLine;
function getCanonicalFileName(fileName) {
    return useCaseSensitiveFileNames ? fileName : fileName.toLowerCase();
}
exports.getCanonicalFileName = getCanonicalFileName;
var formatDiagnosticsHost = {
    getCurrentDirectory: getCurrentDirectory,
    getCanonicalFileName: getCanonicalFileName,
    getNewLine: getNewLine
};
function formatDiagnostics(diagnostics) {
    return ts.formatDiagnostics(diagnostics, formatDiagnosticsHost);
}
exports.formatDiagnostics = formatDiagnostics;
function printDiagnostics(diagnostics) {
    sys.write(formatDiagnostics(diagnostics));
}
exports.printDiagnostics = printDiagnostics;
function parseConfig(fileName) {
    var configFileName = sys.resolvePath(fileName);
    var result = ts.readConfigFile(configFileName, sys.readFile);
    if (result.error) {
        return {
            errors: [result.error],
            options: {},
            fileNames: []
        };
    }
    var configDir = configFileName.substr(0, configFileName.lastIndexOf(path_1.sep));
    return ts.parseJsonConfigFileContent(result.config, sys, configDir, undefined, configFileName);
}
exports.parseConfig = parseConfig;
function createProgram(config) {
    return ts.createProgram(config.fileNames, config.options);
}
exports.createProgram = createProgram;
